/*
 * (c) Copyright IBM Corp 2001, 2006 
 */

package com.ibm.wsdl.tck;

import javax.wsdl.*;
import javax.wsdl.factory.*;
import javax.xml.parsers.*;
import junit.framework.*;
import org.w3c.dom.*;

/**
 * This class implements a series of tests used to check
 * javax.wsdl.BindingOutput implementations for compliance
 * with the JWSDL specification.
 *
 * @author Matthew J. Duftler (duftler@us.ibm.com)
 */
public class BindingOutputTest extends TestCase
{
  private static final String TEST_CANDIDATE_PROPERTY_NAME =
    "javax.wsdl.factory.WSDLFactoryCandidate";
  private static final String NS_URI_WSDL =
    "http://schemas.xmlsoap.org/wsdl/";

  private Definition definition = null;
  private BindingOutput bindingOutput = null;

  protected void setUp() throws WSDLException
  {
    // Determine name of JWSDL factory implementation to test.
    String testCandidateName =
      System.getProperty(TEST_CANDIDATE_PROPERTY_NAME);

    if (testCandidateName == null)
    {
      throw new IllegalArgumentException("System property '" +
                                         TEST_CANDIDATE_PROPERTY_NAME +
                                         "' must be specified to run " +
                                         "test suite.");
    }

    WSDLFactory factory = WSDLFactory.newInstance(testCandidateName);

    Assert.assertNotNull("WSDLFactory should not be null.", factory);

    definition = factory.newDefinition();

    Assert.assertNotNull("Definition should not be null.", definition);

    bindingOutput = definition.createBindingOutput();

    Assert.assertNotNull("BindingOutput should not be null.", bindingOutput);
  }

  /**
   * Test BindingOutput.setDocumentationElement(...) and
   * BindingOutput.getDocumentationElement().
   */
  public void testSetGetDocumentationElement()
    throws ParserConfigurationException
  {
    DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();

    factory.setNamespaceAware(true);
    factory.setValidating(false);

    DocumentBuilder builder = factory.newDocumentBuilder();
    Document doc = builder.newDocument();
    Element el = doc.createElementNS(NS_URI_WSDL,
                                     "wsdl:documentation");

    bindingOutput.setDocumentationElement(el);

    Element el2 = bindingOutput.getDocumentationElement();

    Assert.assertTrue("BindingOutput.getDocumentationElement() did not " +
                      "return the same Element that was set using " +
                      "BindingOutput.setDocumentationElement(...).",
                      el == el2);
  }

  /**
   * Test BindingOutput.setName(...) and BindingOutput.getName().
   */
  public void testSetGetName()
  {
    String name = "abcdef";

    bindingOutput.setName(name);

    String name2 = bindingOutput.getName();

    Assert.assertTrue("BindingOutput.getName() did not return " +
                      "the same name that was set using " +
                      "BindingOutput.setName(...).",
                      name.equals(name2));
  }
}